package net.wicp.tams.duckula.ops.pages.cas;

import java.util.List;

import org.apache.commons.lang3.tuple.Pair;
import org.apache.tapestry5.ioc.annotations.Inject;
import org.apache.tapestry5.util.TextStreamResponse;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;

import cn.hutool.crypto.digest.BCrypt;
import net.wicp.tams.app.duckula.controller.bean.models.SysUser;
import net.wicp.tams.app.duckula.controller.dao.SysUserMapper;
import net.wicp.tams.cas.constant.ColsSysOrg;
import net.wicp.tams.common.Result;
import net.wicp.tams.common.apiext.CollectionUtil;
import net.wicp.tams.common.apiext.PwdUtil;
import net.wicp.tams.common.apiext.StringUtil;
import net.wicp.tams.common.apiext.json.EasyUiAssist;
import net.wicp.tams.common.callback.impl.convertvalue.ConvertValueEnum;
import net.wicp.tams.common.constant.dic.Gender;
import net.wicp.tams.common.constant.dic.YesOrNo;
import net.wicp.tams.common.jdbc.convert.ConvertValueMysql;
import net.wicp.tams.component.tools.TapestryAssist;
import net.wicp.tams.duckula.ops.pages.ParentPage;

public class UserManager extends ParentPage {

	@Inject
	private SysUserMapper sysUserExample;

	public TextStreamResponse onQuery() {
		// ajax.req(key, params);
		final SysUser sysUser = TapestryAssist.getBeanFromPage(SysUser.class, requestGlobals);
		QueryWrapper<SysUser> queryWrapper = new QueryWrapper<SysUser>();
		if (StringUtil.isNotNull(sysUser.getUserName())) {
			queryWrapper.likeRight("user_name", sysUser.getUserName());
		}
		ConvertValueMysql orgCv = new ConvertValueMysql(ColsSysOrg.db, ColsSysOrg.tb, "org_name");

		Pair<List<SysUser>, Long> query = query(sysUserExample, queryWrapper);
		String retstr = EasyUiAssist.getJsonForGridAlias2(query.getLeft(),
				new String[] { "orgId,orgId1", "status,status1", "gender,gender1" },
				CollectionUtil.newMap("orgId1", orgCv, "status1", new ConvertValueEnum(YesOrNo.class), "gender1",
						new ConvertValueEnum(Gender.class)),
				query.getRight());
		return TapestryAssist.getTextStreamResponse(retstr);
	}

	public TextStreamResponse onSave() {
		return saveCommon(SysUser.class, sysUserExample, new IUpdateObj<SysUser>() {
			@Override
			public void doUpdate(SysUser po, boolean isInsert) {
				if (isInsert) {
					po.setPassword(PwdUtil.hashpw("123456"));// 初始化密码
				} else {
					po.setPassword(null);// 不能修改密码
				}
			}
		});
	}

	public TextStreamResponse onDel() {
		return delCommon(sysUserExample);
	}

	public TextStreamResponse onSavePwd() {
		Long id = Long.parseLong(request.getParameter("id"));
		String pwdNew = request.getParameter("pwdNew");
		String pwdNew2 = request.getParameter("pwdNew2");

		if (!pwdNew.equals(pwdNew2)) {
			return TapestryAssist.getTextStreamResponse(Result.getError("密码2次需要一致"));
		}
		String pwdOld = request.getParameter("pwdOld");
		if (StringUtil.isNotNull(pwdOld)) {
			if (pwdOld.equals(pwdNew)) {
				return TapestryAssist.getTextStreamResponse(Result.getError("旧密码与新密码不能相同"));
			}
			SysUser sysUser = sysUserExample.selectById(id);
			// 要不要检查旧密码
			boolean checkpw = BCrypt.checkpw(pwdOld, sysUser.getPassword());
			if (!checkpw) {
				return TapestryAssist.getTextStreamResponse(Result.getError("旧密码错误！"));
			}
		}
		SysUser user = new SysUser();
		user.setId(id);
		user.setPassword(PwdUtil.hashpw(pwdNew));
		sysUserExample.updateByPrimaryKeySelective(user);
		return TapestryAssist.getTextStreamResponse(Result.getSuc());
	}

	public TextStreamResponse onResertPwd() {
		Long id = Long.parseLong(request.getParameter("id"));
		SysUser user = new SysUser();
		user.setId(id);
		user.setPassword(PwdUtil.hashpw("123456"));
		sysUserExample.updateByPrimaryKeySelective(user);
		return TapestryAssist.getTextStreamResponse(Result.getSuc());
	}

}
